@@ -3,6 +3,8 @@ package  # Hide from PAUSE
 
 use base qw(Catalyst::Controller);
 
+use Encode;
+
 sub default : Private {
     my ( $self, $c ) = @_;
 
@@ -86,6 +88,47 @@ sub template_email : Global('template_email') {
     }
 }
 
+sub template_email_utf8 : Global('template_email_utf8') {
+    my ($self, $c, @args) = @_;
+
+    $c->stash->{time} = $c->req->params->{time} || time;
+
+    $c->stash->{chars} = decode('utf-8', "✔ ✈ ✉");
+
+    $c->stash->{email} = {
+        to           => 'test-email@example.com',
+        from         => 'no-reply@example.com',
+        subject      => 'Just a test',
+        content_type => 'multipart/alternative',
+       templates => [
+            {
+                template        => 'text_plain/test.tt',
+                content_type    => 'text/plain',
+                charset      => 'utf-8',
+                encoding     => 'quoted-printable',
+            },
+            {
+                view            => 'TT',
+                template        => 'text_html/test_utf8.tt',
+                content_type    => 'text/html',
+                charset      => 'utf-8',
+                encoding     => 'quoted-printable',
+             },
+        ],
+    };
+
+    $c->forward('TestApp::View::Email::Template');    
+
+    if ( scalar( @{ $c->error } ) ) {
+        $c->res->status(500);
+        $c->res->body('Template Email Failed');
+    } else {
+        $c->res->body('Template Email Ok');
+    }
+}
+
+
+
 sub template_email_app_config : Global('template_email_app_config') {
     my ($self, $c, @args) = @_;
 
